==> amazon-sp-api-1.1.1.tgz: package/lib/resources/fulfillmentInbound.js <==
module.exports = {
  fulfillmentInbound: {
    __versions: ["v0", "2024-03-20"],
    __operations: [
      "createInboundShipmentPlan",
      "updateInboundShipment",
      "createInboundShipment",
      "getPreorderInfo",
      "confirmPreorder",
      "getPrepInstructions",
      "getTransportDetails",
      "putTransportDetails",
      "voidTransport",
      "estimateTransport",
      "confirmTransport",
      "getLabels",
      "getBillOfLading",
      "getShipments",
      "getShipmentItemsByShipmentId",
      "getShipmentItems",
      "listInboundPlans",
      "createInboundPlan",
      "getInboundPlan",
      "listInboundPlanBoxes",
      "cancelInboundPlan",
      "listInboundPlanItems",
      "updateInboundPlanName",
      "listPackingGroupBoxes",
      "listPackingGroupItems",
      "setPackingInformation",
      "listPackingOptions",
      "generatePackingOptions",
      "confirmPackingOption",
      "listInboundPlanPallets",
      "listPlacementOptions",
      "generatePlacementOptions",
      "confirmPlacementOption",
      "getShipment",
      "listShipmentBoxes",
      "listShipmentContentUpdatePreviews",
      "generateShipmentContentUpdatePreviews",
      "getShipmentContentUpdatePreview",
      "confirmShipmentContentUpdatePreview",
      "getDeliveryChallanDocument",
      "listDeliveryWindowOptions",
      "generateDeliveryWindowOptions",
      "confirmDeliveryWindowOptions",
      "listShipmentItems",
      "updateShipmentName",
      "listShipmentPallets",
      "cancelSelfShipAppointment",
      "getSelfShipAppointmentSlots",
      "generateSelfShipAppointmentSlots",
      "scheduleSelfShipAppointment",
      "updateShipmentSourceAddress",
      "updateShipmentTrackingDetails",
      "listTransportationOptions",
      "generateTransportationOptions",
      "confirmTransportationOptions",
      "updateItemComplianceDetails",
      "createMarketplaceItemLabels",
      "getInboundOperationStatus"
    ],
    ...require("./versions/fulfillment_inbound/fulfillmentInbound_v0"),
    ...require("./versions/fulfillment_inbound/fulfillmentInbound_2024-03-20")
  }
};

==> amazon-sp-api-1.1.2.tgz: package/lib/resources/fulfillmentInbound.js <==
module.exports = {
  fulfillmentInbound: {
    __versions: ["v0", "2024-03-20"],
    __operations: [
      "createInboundShipmentPlan",
      "updateInboundShipment",
      "createInboundShipment",
      "getPreorderInfo",
      "confirmPreorder",
      "getPrepInstructions",
      "getTransportDetails",
      "putTransportDetails",
      "voidTransport",
      "estimateTransport",
      "confirmTransport",
      "getLabels",
      "getBillOfLading",
      "getShipments",
      "getShipmentItemsByShipmentId",
      "getShipmentItems",
      "listInboundPlans",
      "createInboundPlan",
      "getInboundPlan",
      "listInboundPlanBoxes",
      "cancelInboundPlan",
      "listInboundPlanItems",
      "updateInboundPlanName",
      "listPackingGroupBoxes",
      "listPackingGroupItems",
      "setPackingInformation",
      "listPackingOptions",
      "generatePackingOptions",
      "confirmPackingOption",
      "listInboundPlanPallets",
      "listPlacementOptions",
      "generatePlacementOptions",
      "confirmPlacementOption",
      "getShipment",
      "listShipmentBoxes",
      "listShipmentContentUpdatePreviews",
      "generateShipmentContentUpdatePreviews",
      "getShipmentContentUpdatePreview",
      "confirmShipmentContentUpdatePreview",
      "getDeliveryChallanDocument",
      "listDeliveryWindowOptions",
      "generateDeliveryWindowOptions",
      "confirmDeliveryWindowOptions",
      "listShipmentItems",
      "updateShipmentName",
      "listShipmentPallets",
      "cancelSelfShipAppointment",
      "getSelfShipAppointmentSlots",
      "generateSelfShipAppointmentSlots",
      "scheduleSelfShipAppointment",
      "updateShipmentSourceAddress",
      "updateShipmentTrackingDetails",
      "listTransportationOptions",
      "generateTransportationOptions",
      "confirmTransportationOptions",
      "updateItemComplianceDetails",
      "createMarketplaceItemLabels",
      "getInboundOperationStatus",
      "listPrepDetails",
      "setPrepDetails"
    ],
    ...require("./versions/fulfillment_inbound/fulfillmentInbound_v0"),
    ...require("./versions/fulfillment_inbound/fulfillmentInbound_2024-03-20")
  }
};
